@@ -425,128 +425,6 @@ void elsym_helper(const vec& b, const ivec& a, int* ptr_first, int* ptr_last, co
 }
 
 
-
-// [[Rcpp::export]]
-Rcpp::List calibrate_Bayes_C(const arma::ivec& a, const arma::ivec& first, const arma::ivec& last, 
-				 const arma::ivec& ib, const arma::ivec& bi, const arma::ivec& nbi, 
-				 const arma::ivec& nib,
-				 arma::ivec& bfirst, arma::ivec& blast,
-				 const arma::ivec& bmax, const arma::ivec& m,
-				 const arma::ivec& sufI, const arma::ivec& bkscoretab,
-				 const arma::vec& b_in,  const arma::vec& fixed_b, 
-				 const int from, const int step, const int ndraws,
-				 const arma::ivec progress_init,
-				 const double prior_eta=0.5, const double prior_rho=0.5)
-{
-
-	const bool free_calibration = all(fixed_b != fixed_b); // NA != NA
-	const int nIter = ndraws * step + from;
-	const int max_cat = max(last-first)+1;
-	
-	progress pb(ndraws, progress_init);
-	
-	// cumulatives for bookkeeping
-	const int nI = nbi.n_elem;
-	ivec cnbi(nI+1);
-	cnbi(0) = 0;
-	cnbi.tail(nI) = cumsum(nbi);
-	
-	const int nB = nib.n_elem;
-	ivec cnib(nB+1);
-	cnib(0) = 0;
-	cnib.tail(nB) = cumsum(nib);
-	
-	ivec cbmax(nB+1);
-	cbmax[0] = 0;	
-	for(int k=0; k<nB; k++)
-		cbmax[k+1] = cbmax[k] + bmax[k]+1;
-	
-
-	const int max_bscore = max(bmax);
-
-	// working variables
-	vec y(max_cat, fill::zeros), z(nB, fill::zeros);
-	vec bklambda(bkscoretab.n_elem, fill::ones);	// to do: fill 0 lijkt beter, onmogelijke scores?
-	mat bklambdax(ndraws, bkscoretab.n_elem);
-	
-	std::vector<long double> g(max_bscore+1);
-	vec pi_k(max_bscore+1, fill::zeros);
-	//vec fpwr(max_bscore+1);
-	//fpwr[0] = 1;
-	
-	// copy b
-	vec b(b_in.memptr(), b_in.n_elem);
-	mat bx(ndraws, b.n_elem);
-	
-	//Gibbs
-	int k,row_index=0;
-	long double sm;
-	
-	for (int iter=0; iter<nIter; iter++)
-	{
-		for (int k=0; k<nB; k++)
-		{
-			elsym_helper(b,a, bfirst.memptr() + cnib[k], blast.memptr() + cnib[k], -1, nib[k], bmax[k], g);
-			
-			sm = 0;
-			for (int s=0; s<=bmax[k];s++)
-			{
-			  if (g[s]>0){
-			    pi_k[s] = R::rgamma(bkscoretab[cbmax[k]+s]+0.1, 1.0);
-			    sm += pi_k[s];
-			  }
-			}
-			
-			for (int s=0; s<=bmax[k];s++)
-			{
-			  if(g[s]>0)
-			  {
-			    pi_k[s] = pi_k[s]/sm;
-			    bklambda[cbmax[k]+s] = (pi_k[s]*m[k])/g[s];
-			  }
-			}
-			
-			z[k] = R::rgamma(m[k], 1.0/m[k]);
-			
-		}
-		// bayes_items
-		for (int i=0; i<nI;i++)
-		{
-			y.zeros();
-			for (int ib_indx=cnbi[i]; ib_indx<cnbi[i+1]; ib_indx++)
-			{
-				k = ib[ib_indx];
-				elsym_helper(b, a, bfirst.memptr() + cnib[k], blast.memptr() + cnib[k], bi[ib_indx], nib[k], bmax[k], g);
-					
-				for (int s=0; s<=bmax[k]-a[last[i]]; s++)
-					for (int j=first[i]+1, c=0; j<=last[i]; j++,c++)
-						y[c] += z[k] * g[s] * bklambda[cbmax[k]+s+a[j]];			
-			}
-
-			for (int j=first[i]+1, c=0; j<=last[i]; j++,c++)
-				b[j] = R::rgamma(sufI[j] + prior_eta, 1/(y[c] + prior_rho));
-		}
-		
-
-		if (!free_calibration)
-		{
-			b.elem(find_finite(fixed_b)) = fixed_b.elem(find_finite(fixed_b));
-		}
-
-		b.replace(datum::nan, 1); 
-		if(iter >= from && (iter-from) % step == 0)
-		{
-			Rcpp::checkUserInterrupt();
-			bklambdax.row(row_index) = bklambda.t();
-			bx.row(row_index++) = b.t();
-			pb.tick();
-		}
-		
-	}
-	return Rcpp::List::create(Rcpp::Named("b") = bx, Rcpp::Named("lambda") = bklambdax);
-}
-
-
 // [[Rcpp::export]]
 Rcpp::List calibrate_Bayes_chains(const arma::ivec& a, const arma::ivec& first, const arma::ivec& last, 
 				 const arma::ivec& ib, const arma::ivec& bi, const arma::ivec& nbi, 
